==> supper_app-0.0.7.tar.gz: lib/src/mini_app_launcher.dart <==
import 'package:flutter/material.dart';
import 'package:shake/shake.dart';
import '../supper_app.dart';

class AppLauncherProps {
  final String appName;
  final BaseModule module;
  final String root;
  final Widget? debugWidget;

  AppLauncherProps(this.appName, this.module, this.root, this.debugWidget);
}

class AppLauncher extends StatefulWidget {
  final AppLauncherProps props;
  const AppLauncher({Key? key, required this.props}) : super(key: key);

  @override
  // ignore: library_private_types_in_public_api
  _AppLauncherState createState() =>
      // ignore: no_logic_in_create_state
      _AppLauncherState(props);
}

class _AppLauncherState extends State<AppLauncher> {
  final AppLauncherProps props;
  _AppLauncherState(this.props);

  @override
  void initState() {
    super.initState();
    if (mounted && props.debugWidget != null) {
      ShakeDetector.autoStart(
        onPhoneShake: () {
          final debugWidget = Center(child: props.debugWidget);
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (_) => Scaffold(body: Center(child: debugWidget))));
        },
        minimumShakeCount: 1,
        shakeSlopTimeMS: 500,
        shakeCountResetTime: 3000,
        shakeThresholdGravity: 2.7,
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(props.appName),
        backgroundColor: Color.fromARGB(255, 222, 104, 14),
      ),
      backgroundColor: Colors.lightBlue[50],
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            InkWell(
              onTap: () {
                Navigator.pushNamed(context, props.root);
              },
              child: Container(
                  color: Color.fromARGB(255, 222, 104, 14),
                  width: 110,
                  height: 45,
                  child: const Center(
                      child: Text(
                    'Start App',
                    textScaleFactor: 1,
                    style: TextStyle(
                        fontWeight: FontWeight.bold, color: Colors.white70),
                  ))),
            ),
          ],
        ),
      ),
    );
  }
}

class MiniApp extends StatelessWidget {
  final AppLauncherProps props;
  const MiniApp({Key? key, required this.props}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "MiniApp",
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: AppLauncher(
        props: props,
      ),
      onGenerateRoute: props.module.onGenerateRoute,
    );
  }
}

==> supper_app-0.0.9.tar.gz: lib/src/mini_app_launcher.dart <==
import 'package:flutter/material.dart';
import 'package:shake/shake.dart';
import '../supper_app.dart';

class AppLauncherProps {
  AppLauncherProps(this.appName, this.module, this.root, this.debugWidget);
  final String appName;
  final BaseModule module;
  final String root;
  final Widget? debugWidget;
}

class AppLauncher extends StatefulWidget {
  const AppLauncher({Key? key, required this.props}) : super(key: key);
  final AppLauncherProps props;

  @override
  // ignore: library_private_types_in_public_api
  _AppLauncherState createState() =>
      // ignore: no_logic_in_create_state
      _AppLauncherState(props);
}

class _AppLauncherState extends State<AppLauncher> {
  _AppLauncherState(this.props);
  final AppLauncherProps props;

  @override
  void initState() {
    super.initState();
    if (mounted && props.debugWidget != null) {
      ShakeDetector.autoStart(
        onPhoneShake: () {
          final Center debugWidget = Center(child: props.debugWidget);
          Navigator.push<void>(
              context,
              MaterialPageRoute<void>(
                  builder: (_) => Scaffold(body: Center(child: debugWidget))));
        },
        minimumShakeCount: 1,
        shakeSlopTimeMS: 500,
        shakeCountResetTime: 3000,
        shakeThresholdGravity: 2.7,
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(props.appName),
        backgroundColor: const Color.fromARGB(255, 222, 104, 14),
      ),
      backgroundColor: Colors.lightBlue[50],
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            InkWell(
              onTap: () {
                Navigator.pushNamed(context, props.root);
              },
              child: Container(
                  color: const Color.fromARGB(255, 222, 104, 14),
                  width: 110,
                  height: 45,
                  child: const Center(
                      child: Text(
                    'Start App',
                    textScaleFactor: 1,
                    style: TextStyle(
                        fontWeight: FontWeight.bold, color: Colors.white70),
                  ))),
            ),
          ],
        ),
      ),
    );
  }
}

class MiniApp extends StatelessWidget {
  const MiniApp({Key? key, required this.props}) : super(key: key);
  final AppLauncherProps props;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'MiniApp',
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: AppLauncher(
        props: props,
      ),
      onGenerateRoute: props.module.onGenerateRoute,
    );
  }
}
